==> esp32c3-0.3.0.crate: esp32c3-0.3.0/src/efuse/wr_tim_conf1.rs <==
#[doc = "Register `WR_TIM_CONF1` reader"]
pub struct R(crate::R<WR_TIM_CONF1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<WR_TIM_CONF1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<WR_TIM_CONF1_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<WR_TIM_CONF1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `WR_TIM_CONF1` writer"]
pub struct W(crate::W<WR_TIM_CONF1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<WR_TIM_CONF1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<WR_TIM_CONF1_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<WR_TIM_CONF1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `PWR_ON_NUM` reader - Configures the power up time for VDDQ."]
pub struct PWR_ON_NUM_R(crate::FieldReader<u16, u16>);
impl PWR_ON_NUM_R {
    pub(crate) fn new(bits: u16) -> Self {
        PWR_ON_NUM_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PWR_ON_NUM_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `PWR_ON_NUM` writer - Configures the power up time for VDDQ."]
pub struct PWR_ON_NUM_W<'a> {
    w: &'a mut W,
}
impl<'a> PWR_ON_NUM_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0xffff << 8)) | ((value as u32 & 0xffff) << 8);
        self.w
    }
}
impl R {
    #[doc = "Bits 8:23 - Configures the power up time for VDDQ."]
    #[inline(always)]
    pub fn pwr_on_num(&self) -> PWR_ON_NUM_R {
        PWR_ON_NUM_R::new(((self.bits >> 8) & 0xffff) as u16)
    }
}
impl W {
    #[doc = "Bits 8:23 - Configures the power up time for VDDQ."]
    #[inline(always)]
    pub fn pwr_on_num(&mut self) -> PWR_ON_NUM_W {
        PWR_ON_NUM_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Configurarion register 1 of eFuse programming timing parameters.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wr_tim_conf1](index.html) module"]
pub struct WR_TIM_CONF1_SPEC;
impl crate::RegisterSpec for WR_TIM_CONF1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [wr_tim_conf1::R](R) reader structure"]
impl crate::Readable for WR_TIM_CONF1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [wr_tim_conf1::W](W) writer structure"]
impl crate::Writable for WR_TIM_CONF1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets WR_TIM_CONF1 to value 0x0028_8000"]
impl crate::Resettable for WR_TIM_CONF1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0x0028_8000
    }
}

==> esp32c3-0.4.0.crate: esp32c3-0.4.0/src/efuse/wr_tim_conf1.rs <==
#[doc = "Register `WR_TIM_CONF1` reader"]
pub struct R(crate::R<WR_TIM_CONF1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<WR_TIM_CONF1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<WR_TIM_CONF1_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<WR_TIM_CONF1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `WR_TIM_CONF1` writer"]
pub struct W(crate::W<WR_TIM_CONF1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<WR_TIM_CONF1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<WR_TIM_CONF1_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<WR_TIM_CONF1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `PWR_ON_NUM` reader - Configures the power up time for VDDQ."]
pub struct PWR_ON_NUM_R(crate::FieldReader<u16, u16>);
impl PWR_ON_NUM_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        PWR_ON_NUM_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PWR_ON_NUM_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `PWR_ON_NUM` writer - Configures the power up time for VDDQ."]
pub struct PWR_ON_NUM_W<'a> {
    w: &'a mut W,
}
impl<'a> PWR_ON_NUM_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0xffff << 8)) | ((value as u32 & 0xffff) << 8);
        self.w
    }
}
impl R {
    #[doc = "Bits 8:23 - Configures the power up time for VDDQ."]
    #[inline(always)]
    pub fn pwr_on_num(&self) -> PWR_ON_NUM_R {
        PWR_ON_NUM_R::new(((self.bits >> 8) & 0xffff) as u16)
    }
}
impl W {
    #[doc = "Bits 8:23 - Configures the power up time for VDDQ."]
    #[inline(always)]
    pub fn pwr_on_num(&mut self) -> PWR_ON_NUM_W {
        PWR_ON_NUM_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Configurarion register 1 of eFuse programming timing parameters.\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wr_tim_conf1]
(index.html) module"]
pub struct WR_TIM_CONF1_SPEC;
impl crate::RegisterSpec for WR_TIM_CONF1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [wr_tim_conf1::R]
(R) reader structure"]
impl crate::Readable for WR_TIM_CONF1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [wr_tim_conf1::W]
(W) writer structure"]
impl crate::Writable for WR_TIM_CONF1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets WR_TIM_CONF1 to value 0x0028_8000"]
impl crate::Resettable for WR_TIM_CONF1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0x0028_8000
    }
}
